"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
function _export(target, all) {
    for(var name in all)Object.defineProperty(target, name, {
        enumerable: true,
        get: all[name]
    });
}
_export(exports, {
    compile: ()=>compile,
    syntax: ()=>syntax
});
const _htmlEscaper = require("html-escaper");
const compile = async (def, keys = new Set())=>{
    // try to extract the definitions if we're given either module or promise
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    const R = (await (await def?.default ?? def))?.default ?? def;
    if (!R) throw new ReferenceError('Could not find definition for language');
    const map = {};
    const parts = [];
    // eslint-disable-next-line prefer-const
    for (let [name, value] of Object.entries(R)){
        keys.add(name);
        if (Array.isArray(value)) {
            map[name] = await compile(value[1], keys);
            value = value[0];
        }
        parts.push(`(?<${name}>${value?.source ?? value})`);
    }
    const regexp = RegExp(parts.join('|'), 'gm');
    regexp.map = map;
    regexp.keys = keys;
    return regexp;
};
const syntax = (regexp, s)=>s.replace(RegExp('(' + regexp.source + ')|(?<catchbad>[&<>"\'])', 'gm'), (...args)=>{
        const groups = args.pop();
        const entries = Object.entries(groups).filter((e)=>e[1] != null);
        if (!entries.length) return '';
        const [tag, value] = entries[0];
        if (tag === 'catchbad') return (0, _htmlEscaper.escape)(value);
        if (regexp.map) {
            const sub = regexp.map[tag];
            if (sub) return `<span class="${tag}-outer">${syntax(sub, value)}</span>`;
        }
        return `<span class="${tag}">${(0, _htmlEscaper.escape)(value)}</span>`;
    });

//# sourceMappingURL=syntax.js.map